# Changelog

<!--next-version-placeholder-->

## v1.1.0 (2022-05-30)
### Feature
* Init event service ([`1ee8c5d`](https://github.com/draganagrbic998/devops_event_service/commit/1ee8c5d790b3805395a5390d4bffc009b0999732))
